<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ja">
<context>
    <name>ReminderDialog</name>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="35"/>
        <source>Restart the computer to use the system and the applications properly</source>
        <translation>システムとアプリケーションが正常に動作するように再起動してください</translation>
    </message>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="36"/>
        <source>Make sure all data had been saved first</source>
        <translation>まずすべてのデータが保存されていることを確認してください</translation>
    </message>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="41"/>
        <source>Cancel</source>
        <translation>キャンセル</translation>
    </message>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="41"/>
        <source>Shut down</source>
        <translation>シャットダウン</translation>
    </message>
    <message>
        <location filename="../src/reboot-reminder-dialog/reminderdialog.cpp" line="44"/>
        <source>Reboot</source>
        <translation>再起動</translation>
    </message>
</context>
</TS>